__author__ = 'gsibble'

from base_types import SDFirstClassObject, SDInterface

class SDGeneralInterface(SDInterface):

    def __init__(self, parent):
        super(SDGeneralInterface, self).__init__(parent)

    @property
    def states(self):
        states = self._swagger_general_api.getAllStates(self._api_key)
        return states

    @property
    def countries(self):
        countries = self._swagger_general_api.getAllStates(self._api_key)

        #TODO:  Sort through and get unique countries
        return countries

    @property
    def languages(self):

        #TODO:  Add languages

        return []


__author__ = 'gsibble'

import sure
from sure import it, this, those, these
import unittest
from subtledata import SubtleData
from api import swagger

from subtledata import sd_collections_general, sd_collections_tickets, sd_collections_locations, sd_collections_users

from subtledata import sd_location, sd_menu, sd_table, sd_ticket, sd_user

class SDTestCase(unittest.TestCase):
    
    def setUp(self):
        self.SD = SubtleData('abcd', use_cache=False)

class SubtleDataObjectTests(SDTestCase):

    def test_SD_object(self):
        this(self.SD.api_key).should.equal('abcd')
        this(self.SD._use_cache).should.equal(False)

        self.SD = SubtleData('1234', use_cache=True)
        this(self.SD.api_key).should.equal('1234')
        this(self.SD._use_cache).should.equal(True)

        this(self.SD._api_client).should.be.an(swagger.ApiClient)
        this(self.SD.Locations).should.be.an(sd_collections_locations.SDLocationCollection)
        this(self.SD.General).should.be.an(sd_collections_general.SDGeneralInterface)
        this(self.SD.Tickets).should.be.an(sd_collections_tickets.SDTicketCollection)
        this(self.SD.Users).should.be.an(sd_collections_users.SDUserCollection)

class GeneralInterfaceTests(SDTestCase):

    def test_states(self):
        this(self.SD.General.states).should.be.an(list)

    def test_countries(self):
        this(self.SD.General.countries).should.be.an(list)

    def test_languages(self):
        this(self.SD.General.languages).should.be.an(list)

class LocationCollectionTests(SDTestCase):

    def test_get_location(self):
        this(self.SD.Locations.get(123)).should.be.an(sd_location.SDLocation)

    def test_filter_location(self):
        this(self.SD.Locations.filter(name='Test')).should.be.an(list)

    def test_all_locations(self):
        this(self.SD.Locations.all).should.be.an(list)

    def test_create_location(self):
        this(self.SD.Locations.create()).should.be.an(sd_location.SDLocation)

class TicketCollectionTests(SDTestCase):

    def test_get_ticket(self):
        this(self.SD.Tickets.get(1234)).should.be.an(sd_ticket.SDTicket)

class UserCollectionTests(SDTestCase):

    def test_all_users(self):
        this(self.SD.Users.all).should.be.an(list)

    def test_get_user(self):
        this(self.SD.Users.get(1234)).should.be.an(sd_user.SDUser)

    def test_create_user(self):
        this(self.SD.Users.create(first_name='Test')).should.be.an(sd_user.SDUser)

    def test_filter_users(self):
        this(self.SD.Users.filter(first_name='Test')).should.be.an(list)

class SDLocationTests(SDTestCase):

    def setUp(self):
        super(SDLocationTests, self).__init__()
        self.Location = self.SD.Locations.get(1234)

    def test_initial_location_attributes(self):
        this(self.Location.id).should.equal(1234)
        this(self.Location.revenue_centers).should.be.an(list)
        this(self.Location.tip_values).should.be.an(list)
        this(self.Location.discount_types).should.be.an(list)
        this(self.Location.terminals).should.be.an(list)
        #TODO:  More attribs

    def test_location_tables(self):
        this(self.Location.tables).should.be.an(list)
        this(self.Location.open_tables).should.be.an(list)

    def test_location_menu(self):
        this(self.Location.menu).should.be.an(sd_menu.SDMenu)

    def test_check_update_menu(self):
        this(self.Location).should.have.property('update_menu')
        #TODO:  Check for updating the menu somehow

    def test_delete(self):
        this(self.Location.delete()).should.equal(None)

    def test_open_tickets(self):
        this(self.Location.tickets.open).should.be.an(list)
        this(self.Location.tickets.filter()).should.be.an(list)

    def test_fetching_ticket(self):
        this(self.Location.tickets.get_with_pos_id(9876)).should.be.an(sd_ticket.SDTicket)

    def test_create_tickets9


__author__ = 'gsibble'

from base_types import SDFirstClassObject
from sd_ticket import SDTicket

class SDTable(SDFirstClassObject):

    def __init__(self, location, swagger_table, use_cache=True):

        super(SDTable, self).__init__(location, use_cache)

        self._swagger_table = swagger_table
        self._location = location
        for attribute in self._swagger_table.swaggerTypes:
            self.__setattr__(attribute, getattr(self._swagger_table, attribute))

    def open_ticket(self, user_id, device_id, number_of_people_in_party=1, business_expense=False, custom_ticket_name=None, return_ticket_details=False):

        if hasattr(self, 'revenue_center_id') and hasattr(self, 'subtledata_id'):
            ticket_body = {
                "revenue_center_id": self.revenue_center_id,
                "number_of_people_in_party": number_of_people_in_party,
                "user_id": user_id,
                "device_id": device_id,
                "table_id": self.subtledata_id,
                "business_expense": business_expense,
                "custom_ticket_name": custom_ticket_name
            }
        else:
            raise KeyError('Table missing key data')

        print ticket_body

        #Send the request
        ticket_response = self._swagger_locations_api.createTicket(self._location._location_id, self._api_key, ticket_type='dine-in', body=ticket_body)

        print ticket_response.ticket_id

        if return_ticket_details:
            #Get the totals
            return SDTicket(self._api_client, ticket_response.ticket_id, user_id)

        else:
            return SDTicket(self._api_client, ticket_response.ticket_id, user_id)


__author__ = 'gsibble'

from base_types import  SDFirstClassObject
from sd_menu import SDMenu
from sd_table import SDTable

class SDLocation(SDFirstClassObject):

    def __init__(self, parent, location_id, include_menu, use_cache, *args, **kwargs):
        super(SDLocation, self).__init__(parent, use_cache)
        self._location_id = location_id

        #Get the location via swagger
        self._swagger_location = self._swagger_locations_api.getLocation(location_id, self._api_key,
                                                                         use_cache=self._use_cache)

        #Set attributes of first class Location to match Swagger Location object
        for attribute in self._swagger_location.swaggerTypes:
            self.__setattr__(attribute, getattr(self._swagger_location, attribute))

        #Set the tables to be our type
        self.tables = [SDTable(self, table) for table in self.tables]

        if include_menu:
            self.update_menu(use_cache)

    def update_menu(self, use_cache=True):

        if not self._use_cache:
            use_cache = False

        self._swagger_menu = self._swagger_locations_api.getLocationMenu(self._location_id, self._api_key,
                                                                         use_cache=use_cache)

    @property
    def menu(self):

        if not hasattr(self, '_swagger_menu'):
            self.update_menu()

        return SDMenu(self, self._swagger_menu)

    @property
    def open_tables(self):
        return []

    def open_ticket_for_dine_in(self, user_id, device_id, table_id, business_expense=False):
        new_ticket_body = {

        }

        #TODO:  Implement Later
        #Return a SDTicket
        pass

    def open_ticket_for_take_out(self, user_id):

        #Return a SDTicket
        pass

    def open_ticket_for_delivery(self, user_id):

        #Return a SDTicket
        pass


"""
Subtledata Python Client Library

AUTHOR

George Sibble
Chief Software Architect
Subtledata, Inc.
george.sibble@subtledata.com
Github:  sibblegp


************TO USE************

LICENSE (The MIT License)

Copyright (c) 2013 Subtledata, Inc. "code@subtledata.com"

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""

__author__ = 'gsibble'

import config

from api import swagger

from base_types import SDFirstClassObject

from sd_collections_locations import SDLocationCollection
from sd_collections_users import SDUserCollection
from sd_collections_general import SDGeneralInterface
from sd_collections_tickets import SDTicketCollection


class SubtleData(object):

    def __init__(self, api_key, use_cache=True, testing=False, internal_debug=True):
        self.api_key = api_key
        self._use_cache = use_cache
        self._internal_debug = internal_debug

        if not testing:
            self._api_client = swagger.ApiClient(api_key, config.SD_ENDPOINT)
        else:
            self._api_client = swagger.ApiClient(api_key, config.SD_TESTING_ENDPOINT)

        self.Locations = SDLocationCollection(self)
        self.Users = SDUserCollection(self)
        self.Tickets = SDTicketCollection(self)
        self.General = SDGeneralInterface(self)


#!/usr/bin/env python
"""Add all of the modules in the current directory to __all__"""
import os

__all__ = []

for module in os.listdir(os.path.dirname(__file__)):
    if module != '__init__.py' and module[-3:] == '.py':
        __all__.append(module[:-3])




__author__ = 'gsibble'

from base_types import SDFirstClassObject
import constants as C

class SDTicket(SDFirstClassObject):
    def __init__(self, parent, ticket_id, user_id=None, get_values=True, *args, **kwargs):
        super(SDTicket, self).__init__(parent, False)

        self.ticket_id = ticket_id
        self.user_id = user_id

        if get_values == True:
            pass
            #TODO:  Implement this
            # self._swagger_ticket = self._swagger_tickets_api.getTicket(ticket_id, user_id)
            #
            # if self._swagger_ticket is not None:
            #     for attribute in self._swagger_ticket.swaggerTypes:
            #         self.__setattr__(attribute, getattr(self._swagger_ticket, attribute))

    def add_item_to_order(self, item_id, quantity, instructions=None, modifiers=None):

        if hasattr(self, 'user_id') and hasattr(self, 'ticket_id'):
            if self.user_id is not None and self.ticket_id is not None:
                post_body = {
                    'item_id': int(item_id),
                    'quantity': quantity,

                    }

                if instructions is not None:
                    post_body['instructions'] = instructions

                if modifiers is not None:
                    post_body['modifiers'] = modifiers

                print post_body

                returned_status = self._swagger_tickets_api.addItemsToOrder(self.ticket_id, self.user_id, self._api_key,
                                                                            body=post_body)

                return returned_status

            else:

                raise C.NoUserSetOnTicket
        else:
            raise C.NoUserSetOnTicket

    def submit_order(self):

        if hasattr(self, 'user_id') and hasattr(self, 'ticket_id'):
            if self.user_id is not None and self.ticket_id is not None:

                returned_status = self._swagger_tickets_api.submitOrder(self.ticket_id, self.user_id, self._api_key,
                                                                        body={'send': True})

                return returned_status
            else:
                raise C.NoUserSetOnTicket
        else:
            raise C.NoUserSetOnTicket


#!/usr/bin/env python
"""
WordAPI.py
Copyright 2012 Wordnik, Inc.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
"""
import sys
import os

from models import *


class UsersApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient

    
    def createUser(self, api_key, body, **kwargs):
        """Create a user

        Args:
            api_key, str: Subtledata API Key (required)
            body, NewUser: New User Object (required)
            
        Returns: User
        """

        allParams = ['api_key', 'body']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method createUser" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/users'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'User')
        return responseObject
        
        
    def getUser(self, user_id, api_key, **kwargs):
        """Get a user by ID

        Args:
            user_id, int: Subtledata User ID (required)
            api_key, str: Subtledata API Key (required)
            use_cache, bool: Utilize Cached Data (optional)
            
        Returns: User
        """

        allParams = ['user_id', 'api_key', 'use_cache']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getUser" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/users/{user_id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('use_cache' in params):
            queryParams['use_cache'] = self.apiClient.toPathValue(params['use_cache'])
        if ('user_id' in params):
            replacement = str(self.apiClient.toPathValue(params['user_id']))
            resourcePath = resourcePath.replace('{' + 'user_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'User')
        return responseObject
        
        
    def updateUser(self, user_id, api_key, **kwargs):
        """Update a user

        Args:
            user_id, int: Subtledata User ID (required)
            api_key, str: Subtledata API Key (required)
            
        Returns: User
        """

        allParams = ['user_id', 'api_key']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateUser" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/users/{user_id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('user_id' in params):
            replacement = str(self.apiClient.toPathValue(params['user_id']))
            resourcePath = resourcePath.replace('{' + 'user_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'User')
        return responseObject
        
        
    def deleteUser(self, user_id, api_key, **kwargs):
        """Delete a user

        Args:
            user_id, int: Subtledata User ID (required)
            api_key, str: Subtledata API Key (required)
            
        Returns: Status
        """

        allParams = ['user_id', 'api_key']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteUser" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/users/{user_id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('user_id' in params):
            replacement = str(self.apiClient.toPathValue(params['user_id']))
            resourcePath = resourcePath.replace('{' + 'user_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'Status')
        return responseObject
        
        
    def searchUsersByName(self, user_name, api_key, **kwargs):
        """Search for a user by name

        Args:
            user_name, str: Subtledata User Name (required)
            api_key, str: Subtledata API Key (required)
            use_cache, bool: Utilize Cached Data (optional)
            
        Returns: User
        """

        allParams = ['user_name', 'api_key', 'use_cache']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method searchUsersByName" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/users/search/name/{user_name}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('use_cache' in params):
            queryParams['use_cache'] = self.apiClient.toPathValue(params['use_cache'])
        if ('user_name' in params):
            replacement = str(self.apiClient.toPathValue(params['user_name']))
            resourcePath = resourcePath.replace('{' + 'user_name' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'User')
        return responseObject
        
        
    def getUsersCards(self, user_id, api_key, **kwargs):
        """Get a list of stored cards for a user

        Args:
            user_id, int: SubtleData User ID (required)
            api_key, str: Subtledata API Key (required)
            
        Returns: list[Card]
        """

        allParams = ['user_id', 'api_key']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getUsersCards" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/users/{user_id}/cards'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('user_id' in params):
            replacement = str(self.apiClient.toPathValue(params['user_id']))
            resourcePath = resourcePath.replace('{' + 'user_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'list[Card]')
        return responseObject
        
        
    def createCardForUser(self, user_id, api_key, body, **kwargs):
        """Create a card for a user

        Args:
            user_id, int: SubtleData User ID (required)
            api_key, str: Subtledata API Key (required)
            body, NewCard: New Card Object (required)
            
        Returns: CardStatus
        """

        allParams = ['user_id', 'api_key', 'body']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method createCardForUser" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/users/{user_id}/cards'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('user_id' in params):
            replacement = str(self.apiClient.toPathValue(params['user_id']))
            resourcePath = resourcePath.replace('{' + 'user_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CardStatus')
        return responseObject
        
        
    





#!/usr/bin/env python
"""
Copyright 2012 Wordnik, Inc.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""
class Location:
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        self.swaggerTypes = {
            'cross_streets': 'str',
            'receipt_number_instructions': 'str',
            'employee_request_through_app': 'bool',
            'menu_ordering_available': 'bool',
            'payment_via_credit_card_available_message': 'str',
            'postal_code': 'str',
            'Latitude': 'float',
            'location_id': 'int',
            'app_specials': 'bool',
            'user_rating': 'str',
            'location_name': 'str',
            'tender_types': 'list[TenderType]',
            'process_new_credit_cards': 'bool',
            'table_number_instructions': 'str',
            'state': 'str',
            'color_theme': 'int',
            'logo_url': 'str',
            'website_url': 'str',
            'revenue_centers': 'list[RevenueCenter]',
            'city': 'str',
            'ordering_available_message': 'str',
            'phone': 'str',
            'terminals': 'list[Terminal]',
            'location_picture_url': 'str',
            'favorites_ordering_available': 'bool',
            'neighborhood_name': 'str',
            'discount_types': 'list[DiscountType]',
            'longitude': 'float',
            'price_rating': 'int',
            'process_pre_authed_cards': 'bool',
            'address_line_2': 'str',
            'address_line_1': 'str'

        }


        #Cross Streets
        self.cross_streets = None # str
        #Receipt number instructions
        self.receipt_number_instructions = None # str
        #Request for help throguh the app
        self.employee_request_through_app = None # bool
        #Menu Available
        self.menu_ordering_available = None # bool
        #Payment via credit card available message
        self.payment_via_credit_card_available_message = None # str
        #Address Postal Code
        self.postal_code = None # str
        #Location Latitude
        self.Latitude = None # float
        #Location ID
        self.location_id = None # int
        #Specials available through app
        self.app_specials = None # bool
        #User Rating
        self.user_rating = None # str
        #Location Name
        self.location_name = None # str
        self.tender_types = None # list[TenderType]
        #Process New Credit Cards
        self.process_new_credit_cards = None # bool
        #Table number instructions
        self.table_number_instructions = None # str
        #Address State
        self.state = None # str
        #Color Theme
        self.color_theme = None # int
        #Logo URL
        self.logo_url = None # str
        #Website URL
        self.website_url = None # str
        self.revenue_centers = None # list[RevenueCenter]
        #Address City
        self.city = None # str
        #Ordering available message
        self.ordering_available_message = None # str
        #Phone Number
        self.phone = None # str
        self.terminals = None # list[Terminal]
        #Location Picture URL
        self.location_picture_url = None # str
        #Favorites available for ordering
        self.favorites_ordering_available = None # bool
        #Neighborhood Name
        self.neighborhood_name = None # str
        self.discount_types = None # list[DiscountType]
        #Location Longitude
        self.longitude = None # float
        #Price Rating
        self.price_rating = None # int
        #Process Pre Authed Credit Cards
        self.process_pre_authed_cards = None # bool
        #Address Line 2
        self.address_line_2 = None # str
        #Address Line 1
        self.address_line_1 = None # str
        



__author__ = 'gsibble'

from base_types import SDFirstClassCollection
from sd_ticket import SDTicket

class SDTicketCollection(SDFirstClassCollection):

    def __init__(self, parent):
        super(SDTicketCollection, self).__init__(parent)

    def get(self, ticket_id, user_id=None):
        return SDTicket(self._api_client, ticket_id=ticket_id, user_id=user_id)


__author__ = 'gsibble'

from base_types import SDFirstClassObject

class SDMenu(SDFirstClassObject):

    def __init__(self, location, swagger_menu, use_cache=True):

        super(SDMenu, self).__init__(location, use_cache)

        #Store parent location
        self._location = location

        #Set up the public lists
        self.items = []
        self.categories = swagger_menu

        #Set up the private item dictionaries
        self._item_name_dict = {}
        self._item_id_dict = {}

        #Set up private category dictionaries
        self._category_name_dict = {}
        self._category_id_dict = {}

        for category in swagger_menu:
            self._category_name_dict[category.category_name] = category
            self._category_id_dict[category.category_id] = category

            #Store the items
            for item in category.items:
                setattr(item, 'category', category.category_name)
                self.items.append(item)
                self._item_name_dict[item.name] = item
                self._item_id_dict[item.item_id] = item

    def get_category(self, category_id=None, category_name=None):

        category_object = None

        if category_id is not None:
            category_object = self._category_id_dict[category_id]
        elif category_name is not None:
            category_object = self._category_name_dict[category_name]

        return category_object

    def get_item(self, item_id=None, item_name=None):

        item_object = None

        if item_id is not None:
            item_object = self._item_id_dict[item_id]
        elif item_name is not None:
            item_object = self._category_name_dict[item_name]

        return item_object


__author__ = 'gsibble'

from api.LocationsApi import LocationsApi
from api.UsersApi import UsersApi
from api.TicketsApi import TicketsApi
from api.GeneralApi import GeneralApi

class SDInterface(object):

    def __init__(self, parent, *args, **kwargs):
        if hasattr(parent, 'api_key'):
            self._api_key = parent.api_key
        else:
            self._api_key = parent._api_key
        self._use_cache = parent._use_cache
        self._api_client = parent._api_client
        self._swagger_locations_api = LocationsApi(self._api_client)
        self._swagger_users_api = UsersApi(self._api_client)
        self._swagger_tickets_api = TicketsApi(self._api_client)
        self._swagger_general_api = GeneralApi(self._api_client)

class SDFirstClassCollection(SDInterface):

    def __init__(self, parent, *args, **kwargs):
        super(SDFirstClassCollection, self).__init__(parent)



class SDFirstClassObject(SDInterface):
    def __init__(self, parent, use_cache=True, *args, **kwargs):
        super(SDFirstClassObject, self).__init__(parent)

        #Override use cache if not already set to False
        if self._use_cache:
            self._use_cache = use_cache


__author__ = 'gsibble'

from base_types import SDFirstClassCollection

from sd_location import SDLocation

class SDLocationCollection(SDFirstClassCollection):

    def __init__(self, parent):
        super(SDLocationCollection, self).__init__(parent)

    @property
    def all(self):
        #TODO:  Return all locations
        return []

    def get(self, location_id, use_cache=True, include_menu=False):
        if not self._use_cache:
            use_cache = False

        return SDLocation(self, location_id, include_menu, use_cache)

    def filter(self, name=None, postal_code=None):

        return []

    def near(self, latitude, longitude, radius):

        return []

    def create(self):
        pass



#!/usr/bin/env python
"""Wordnik.com's Swagger generic API client. This client handles the client-
server communication, and is invariant across implementations. Specifics of
the methods and models for each application are generated from the Swagger
templates."""

import sys
import os
import re
import urllib
import urllib2
import httplib
import json
import datetime

from models import *


class ApiClient:
    """Generic API client for Swagger client library builds"""

    def __init__(self, apiKey=None, apiServer=None):
        if apiKey == None:
            raise Exception('You must pass an apiKey when instantiating the '
                            'APIClient')
        self.apiKey = apiKey
        self.apiServer = apiServer
        self.cookie = None

    def callAPI(self, resourcePath, method, queryParams, postData,
                headerParams=None):

        url = self.apiServer + resourcePath
        headers = {}
        if headerParams:
            for param, value in headerParams.iteritems():
                headers[param] = value

        headers['Content-type'] = 'application/json'
        headers['api_key'] = self.apiKey

        if self.cookie:
            headers['Cookie'] = self.cookie

        data = None

        if queryParams:
            # Need to remove None values, these should not be sent
            sentQueryParams = {}
            for param, value in queryParams.items():
                if value != None:
                    sentQueryParams[param] = value
            url = url + '?' + urllib.urlencode(sentQueryParams)

        if method in ['GET']:

            #Options to add statements later on and for compatibility
            pass

        elif method in ['POST', 'PUT', 'DELETE']:

            if postData:
                headers['Content-type'] = 'application/json'
                data = self.sanitizeForSerialization(postData)
                data = json.dumps(data)

        else:
            raise Exception('Method ' + method + ' is not recognized.')

        request = MethodRequest(method=method, url=url, headers=headers,
                                data=data)

        # Make the request
        response = urllib2.urlopen(request)
        if 'Set-Cookie' in response.headers:
            self.cookie = response.headers['Set-Cookie']
        string = response.read()

        try:
            data = json.loads(string)
        except ValueError:  # PUT requests don't return anything
            data = None

        return data

    def toPathValue(self, obj):
        """Convert a string or object to a path-friendly value
        Args:
            obj -- object or string value
        Returns:
            string -- quoted value
        """
        if type(obj) == list:
            return urllib.quote(','.join(obj))
        else:
            return urllib.quote(str(obj))

    def sanitizeForSerialization(self, obj):
        """Dump an object into JSON for POSTing."""

        if type(obj) == type(None):
            return None
        elif type(obj) in [str, int, long, float, bool]:
            return obj
        elif type(obj) == list:
            return [self.sanitizeForSerialization(subObj) for subObj in obj]
        elif type(obj) == datetime.datetime:
            return obj.isoformat()
        else:
            if type(obj) == dict:
                objDict = obj
            else:
                objDict = obj.__dict__
            return {key: self.sanitizeForSerialization(val)
                    for (key, val) in objDict.iteritems()
                    if key != 'swaggerTypes'}

        if type(postData) == list:
            # Could be a list of objects
            if type(postData[0]) in safeToDump:
                data = json.dumps(postData)
            else:
                data = json.dumps([datum.__dict__ for datum in postData])
        elif type(postData) not in safeToDump:
            data = json.dumps(postData.__dict__)

    def deserialize(self, obj, objClass):
        """Derialize a JSON string into an object.

        Args:
            obj -- string or object to be deserialized
            objClass -- class literal for deserialzied object, or string
                of class name
        Returns:
            object -- deserialized object"""

        # Have to accept objClass as string or actual type. Type could be a
        # native Python type, or one of the model classes.
        if type(objClass) == str:
            if 'list[' in objClass:
                match = re.match('list\[(.*)\]', objClass)
                subClass = match.group(1)
                return [self.deserialize(subObj, subClass) for subObj in obj]

            if (objClass in ['int', 'float', 'long', 'dict', 'list', 'str', 'bool', 'datetime']):
                objClass = eval(objClass)
            else:  # not a native type, must be model class
                objClass = eval(objClass + '.' + objClass)

        if objClass in [int, long, float, dict, list, str, bool]:
            return objClass(obj)
        elif objClass == datetime:
            # Server will always return a time stamp in UTC, but with
            # trailing +0000 indicating no offset from UTC. So don't process
            # last 5 characters.
            return datetime.datetime.strptime(obj[:-5],
                                              "%Y-%m-%dT%H:%M:%S.%f")

        instance = objClass()

        for attr, attrType in instance.swaggerTypes.iteritems():
            if attr in obj:
                value = obj[attr]
                if attrType in ['str', 'int', 'long', 'float', 'bool']:
                    attrType = eval(attrType)
                    try:
                        value = attrType(value)
                    except UnicodeEncodeError:
                        value = unicode(value)
                    except TypeError:
                        value = value
                    setattr(instance, attr, value)
                elif (attrType == 'datetime'):
                    setattr(instance, attr, datetime.datetime.strptime(value[:-5],
                                              "%Y-%m-%dT%H:%M:%S.%f"))
                elif 'list[' in attrType:
                    match = re.match('list\[(.*)\]', attrType)
                    subClass = match.group(1)
                    subValues = []
                    if not value:
                        setattr(instance, attr, None)
                    else:
                        for subValue in value:
                            subValues.append(self.deserialize(subValue,
                                                              subClass))
                    setattr(instance, attr, subValues)
                else:
                    setattr(instance, attr, self.deserialize(value,
                                                             objClass))

        return instance


class MethodRequest(urllib2.Request):

    def __init__(self, *args, **kwargs):
        """Construct a MethodRequest. Usage is the same as for
        `urllib2.Request` except it also takes an optional `method`
        keyword argument. If supplied, `method` will be used instead of
        the default."""

        if 'method' in kwargs:
            self.method = kwargs.pop('method')
        return urllib2.Request.__init__(self, *args, **kwargs)

    def get_method(self):
        return getattr(self, 'method', urllib2.Request.get_method(self))





__author__ = 'gsibble'

from base_types import SDFirstClassCollection

from sd_user import SDUser

class SDUserCollection(SDFirstClassCollection):

    def __init__(self, parent):
        super(SDUserCollection, self).__init__(parent)

    @property
    def all(self):

        return []


    def get(self, user_id, use_cache=True):
        if not self._use_cache:
            use_cache = False

        return SDUser(self, user_id=user_id, use_cache=use_cache)

    def filter(self, first_name=None):

        return []

    def create(self, first_name):
        pass


from distutils.core import setup

setup(
    name='subtledata',
    version='0.0.7-2',
    packages=['subtledata', 'subtledata.api', 'subtledata.api.models'],
    url='http://dev.subtledata.com/libraries/python',
    license='MIT',
    author='George Sibble',
    author_email='george.sibble@subtledata.com',
    description='Integration Library for the Subtledata Platform',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Programming Language :: Python',
        'Topic :: Office/Business :: Financial :: Point-Of-Sale',
        'Topic :: Software Development :: Libraries :: Python Modules'
        ],
)



__author__ = 'gsibble'

from base_types import SDFirstClassObject

class SDUser(SDFirstClassObject):
    def __init__(self, parent, user_id=False, user_name=None, use_cache=True, *args, **kwargs):
        super(SDUser, self).__init__(parent, use_cache)

        if user_id is not None:
            self._swagger_user = self._swagger_users_api.getUser(user_id, self._api_key, use_cache=self._use_cache)
        elif user_name is not None:
            self._swagger_user = self._swagger_users_api.searchUsersByName(user_name, self._api_key,
                                                                           use_cache=self._use_cache)
        else:
            self._swagger_user = None

        if self._swagger_user is not None:
            for attribute in self._swagger_user.swaggerTypes:
                self.__setattr__(attribute, getattr(self._swagger_user, attribute))

    def update_info(self):
        pass


#!/usr/bin/env python
"""
WordAPI.py
Copyright 2012 Wordnik, Inc.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
"""
import sys
import os

from models import *


class LocationsApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient

    
    def getAllLocations(self, api_key, **kwargs):
        """Get all of your locations

        Args:
            api_key, str: Subtledata API Key (required)
            use_cache, bool: Utilize Cached Data (optional)
            
        Returns: list[Location]
        """

        allParams = ['api_key', 'use_cache']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getAllLocations" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('use_cache' in params):
            queryParams['use_cache'] = self.apiClient.toPathValue(params['use_cache'])
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'list[Location]')
        return responseObject
        
        
    def createLocation(self, api_key, body, **kwargs):
        """Create a ticket

        Args:
            api_key, str: Subtledata API Key (required)
            body, NewTicket: New Ticket Object (required)
            
        Returns: TicketStatus
        """

        allParams = ['api_key', 'body']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method createLocation" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TicketStatus')
        return responseObject
        
        
    def getLocationsNear(self, api_key, latitude, longitude, radius, **kwargs):
        """Get locations near a GPS coordinate

        Args:
            api_key, str: Subtledata API Key (required)
            use_cache, bool: Utilize Cached Data (optional)
            latitude, float: Latitude floating point value of search coordinate (required)
            longitude, float: Longitude floating point value of search coordinate (required)
            radius, float: Distance (in miles) to search near coordinate (required)
            
        Returns: list[Location]
        """

        allParams = ['api_key', 'use_cache', 'latitude', 'longitude', 'radius']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getLocationsNear" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations/filter/near'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('use_cache' in params):
            queryParams['use_cache'] = self.apiClient.toPathValue(params['use_cache'])
        if ('latitude' in params):
            queryParams['latitude'] = self.apiClient.toPathValue(params['latitude'])
        if ('longitude' in params):
            queryParams['longitude'] = self.apiClient.toPathValue(params['longitude'])
        if ('radius' in params):
            queryParams['radius'] = self.apiClient.toPathValue(params['radius'])
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'list[Location]')
        return responseObject
        
        
    def getLocation(self, location_id, api_key, **kwargs):
        """Get a location by ID

        Args:
            location_id, int: Subtledata Location ID (required)
            api_key, str: Subtledata API Key (required)
            use_cache, bool: Utilize Cached Data (optional)
            
        Returns: Location
        """

        allParams = ['location_id', 'api_key', 'use_cache']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getLocation" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations/{location_id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('use_cache' in params):
            queryParams['use_cache'] = self.apiClient.toPathValue(params['use_cache'])
        if ('location_id' in params):
            replacement = str(self.apiClient.toPathValue(params['location_id']))
            resourcePath = resourcePath.replace('{' + 'location_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'Location')
        return responseObject
        
        
    def updateLocation(self, location_id, api_key, **kwargs):
        """Update a location

        Args:
            location_id, int: Subtledata Location ID (required)
            api_key, str: Subtledata API Key (required)
            
        Returns: Status
        """

        allParams = ['location_id', 'api_key']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateLocation" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations/{location_id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('location_id' in params):
            replacement = str(self.apiClient.toPathValue(params['location_id']))
            resourcePath = resourcePath.replace('{' + 'location_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'Status')
        return responseObject
        
        
    def deleteLocation(self, location_id, api_key, **kwargs):
        """Delete a location

        Args:
            location_id, int: Subtledata Location ID (required)
            api_key, str: Subtledata API Key (required)
            
        Returns: Status
        """

        allParams = ['location_id', 'api_key']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteLocation" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations/{location_id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('location_id' in params):
            replacement = str(self.apiClient.toPathValue(params['location_id']))
            resourcePath = resourcePath.replace('{' + 'location_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'Status')
        return responseObject
        
        
    def getLocationMenu(self, location_id, api_key, **kwargs):
        """Get a location's Menu

        Args:
            location_id, int: Subtledata Location ID (required)
            api_key, str: Subtledata API Key (required)
            use_cache, bool: Utilize Cached Data (optional)
            
        Returns: list[Category]
        """

        allParams = ['location_id', 'api_key', 'use_cache']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getLocationMenu" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations/{location_id}/menu'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('use_cache' in params):
            queryParams['use_cache'] = self.apiClient.toPathValue(params['use_cache'])
        if ('location_id' in params):
            replacement = str(self.apiClient.toPathValue(params['location_id']))
            resourcePath = resourcePath.replace('{' + 'location_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'list[Category]')
        return responseObject
        
        
    def getTableList(self, location_id, api_key, **kwargs):
        """Get a list of tables by location ID

        Args:
            location_id, int: Subtledata Location ID (required)
            api_key, str: Subtledata API Key (required)
            
        Returns: TableList
        """

        allParams = ['location_id', 'api_key']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTableList" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations/{location_id}/tables'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('location_id' in params):
            replacement = str(self.apiClient.toPathValue(params['location_id']))
            resourcePath = resourcePath.replace('{' + 'location_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TableList')
        return responseObject
        
        
    def getTickets(self, location_id, api_key, **kwargs):
        """Get a list of tickets by location ID

        Args:
            location_id, int: Subtledata Location ID (required)
            api_key, str: Subtledata API Key (required)
            
        Returns: list[Ticket]
        """

        allParams = ['location_id', 'api_key']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTickets" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations/{location_id}/tickets'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('location_id' in params):
            replacement = str(self.apiClient.toPathValue(params['location_id']))
            resourcePath = resourcePath.replace('{' + 'location_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'list[Ticket]')
        return responseObject
        
        
    def createTicket(self, location_id, api_key, body, **kwargs):
        """Create a ticket

        Args:
            location_id, int: Subtledata Location ID (required)
            api_key, str: Subtledata API Key (required)
            ticket_type, str: Order Type (optional)
            body, NewTicket: New Ticket Object (required)
            
        Returns: TicketStatus
        """

        allParams = ['location_id', 'api_key', 'ticket_type', 'body']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method createTicket" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations/{location_id}/tickets'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('ticket_type' in params):
            queryParams['ticket_type'] = self.apiClient.toPathValue(params['ticket_type'])
        if ('location_id' in params):
            replacement = str(self.apiClient.toPathValue(params['location_id']))
            resourcePath = resourcePath.replace('{' + 'location_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TicketStatus')
        return responseObject
        
        
    def getTable(self, location_id, table_id, api_key, **kwargs):
        """Get a table by location ID and unique ID

        Args:
            location_id, int: Subtledata Location ID (required)
            table_id, int: Subtledata Location ID (required)
            api_key, str: Subtledata API Key (required)
            
        Returns: TableDetails
        """

        allParams = ['location_id', 'table_id', 'api_key']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTable" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations/{location_id}/tables/{table_id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('location_id' in params):
            replacement = str(self.apiClient.toPathValue(params['location_id']))
            resourcePath = resourcePath.replace('{' + 'location_id' + '}',
                                                replacement)
        if ('table_id' in params):
            replacement = str(self.apiClient.toPathValue(params['table_id']))
            resourcePath = resourcePath.replace('{' + 'table_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TableDetails')
        return responseObject
        
        
    def getTicket(self, location_id, ticket_id, api_key, **kwargs):
        """Get a ticket by ID

        Args:
            location_id, int: SubtleData Location ID (required)
            ticket_id, int: SubtleData Location ID (required)
            api_key, str: Subtledata API Key (required)
            user_id, int:  (optional)
            
        Returns: Ticket
        """

        allParams = ['location_id', 'ticket_id', 'api_key', 'user_id']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTicket" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations/{location_id}/tickets/{ticket_id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('user_id' in params):
            queryParams['user_id'] = self.apiClient.toPathValue(params['user_id'])
        if ('location_id' in params):
            replacement = str(self.apiClient.toPathValue(params['location_id']))
            resourcePath = resourcePath.replace('{' + 'location_id' + '}',
                                                replacement)
        if ('ticket_id' in params):
            replacement = str(self.apiClient.toPathValue(params['ticket_id']))
            resourcePath = resourcePath.replace('{' + 'ticket_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'Ticket')
        return responseObject
        
        
    def voidTicket(self, location_id, ticket_id, api_key, **kwargs):
        """Void a ticket

        Args:
            location_id, int: SubtleData Location ID (required)
            ticket_id, int: SubtleData Location ID (required)
            api_key, str: Subtledata API Key (required)
            user_id, int:  (optional)
            
        Returns: Status
        """

        allParams = ['location_id', 'ticket_id', 'api_key', 'user_id']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method voidTicket" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations/{location_id}/tickets/{ticket_id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('user_id' in params):
            queryParams['user_id'] = self.apiClient.toPathValue(params['user_id'])
        if ('location_id' in params):
            replacement = str(self.apiClient.toPathValue(params['location_id']))
            resourcePath = resourcePath.replace('{' + 'location_id' + '}',
                                                replacement)
        if ('ticket_id' in params):
            replacement = str(self.apiClient.toPathValue(params['ticket_id']))
            resourcePath = resourcePath.replace('{' + 'ticket_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'Status')
        return responseObject
        
        
    def submitOrder(self, location_id, ticket_id, user_id, api_key, body, **kwargs):
        """Order the currently staged items

        Args:
            location_id, int: SubtleData Location ID (required)
            ticket_id, int: SubtleData Location ID (required)
            user_id, int: SubtleData Location ID (required)
            api_key, str: Subtledata API Key (required)
            body, SendTicket: Send the ticket (required)
            
        Returns: OrderResults
        """

        allParams = ['location_id', 'ticket_id', 'user_id', 'api_key', 'body']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method submitOrder" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations/{location_id}/tickets/{ticket_id}/users/{user_id}/order'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('location_id' in params):
            replacement = str(self.apiClient.toPathValue(params['location_id']))
            resourcePath = resourcePath.replace('{' + 'location_id' + '}',
                                                replacement)
        if ('ticket_id' in params):
            replacement = str(self.apiClient.toPathValue(params['ticket_id']))
            resourcePath = resourcePath.replace('{' + 'ticket_id' + '}',
                                                replacement)
        if ('user_id' in params):
            replacement = str(self.apiClient.toPathValue(params['user_id']))
            resourcePath = resourcePath.replace('{' + 'user_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'OrderResults')
        return responseObject
        
        
    def addItemsToOrder(self, location_id, ticket_id, user_id, api_key, body, **kwargs):
        """Add items to currently staged order on a ticket

        Args:
            location_id, int: SubtleData Location ID (required)
            ticket_id, int: SubtleData Location ID (required)
            user_id, int: SubtleData Location ID (required)
            api_key, str: Subtledata API Key (required)
            body, ItemToAdd: The Item object to Add (required)
            
        Returns: Status
        """

        allParams = ['location_id', 'ticket_id', 'user_id', 'api_key', 'body']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method addItemsToOrder" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations/{location_id}/tickets/{ticket_id}/users/{user_id}/order'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('location_id' in params):
            replacement = str(self.apiClient.toPathValue(params['location_id']))
            resourcePath = resourcePath.replace('{' + 'location_id' + '}',
                                                replacement)
        if ('ticket_id' in params):
            replacement = str(self.apiClient.toPathValue(params['ticket_id']))
            resourcePath = resourcePath.replace('{' + 'ticket_id' + '}',
                                                replacement)
        if ('user_id' in params):
            replacement = str(self.apiClient.toPathValue(params['user_id']))
            resourcePath = resourcePath.replace('{' + 'user_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'Status')
        return responseObject
        
        
    def discountTicket(self, location_id, ticket_id, api_key, body, **kwargs):
        """Discount a ticket

        Args:
            location_id, int: SubtleData Location ID (required)
            ticket_id, int: SubtleData Location ID (required)
            api_key, str: Subtledata API Key (required)
            body, DiscountInfo: Details regarding the discount (required)
            
        Returns: Status
        """

        allParams = ['location_id', 'ticket_id', 'api_key', 'body']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method discountTicket" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/locations/{location_id}/tickets/{ticket_id}/discount'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('location_id' in params):
            replacement = str(self.apiClient.toPathValue(params['location_id']))
            resourcePath = resourcePath.replace('{' + 'location_id' + '}',
                                                replacement)
        if ('ticket_id' in params):
            replacement = str(self.apiClient.toPathValue(params['ticket_id']))
            resourcePath = resourcePath.replace('{' + 'ticket_id' + '}',
                                                replacement)
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'Status')
        return responseObject
        
        
    





#!/usr/bin/env python
"""
WordAPI.py
Copyright 2012 Wordnik, Inc.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
"""
import sys
import os

from models import *


class GeneralApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient

    
    def getAllStates(self, api_key, **kwargs):
        """Get all state identifiers

        Args:
            api_key, str: Subtledata API Key (required)
            use_cache, bool: Utilize Cached Data (optional)
            
        Returns: State
        """

        allParams = ['api_key', 'use_cache']

        params = locals()
        for (key, val) in params['kwargs'].iteritems():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getAllStates" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/general/states'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}

        if ('api_key' in params):
            queryParams['api_key'] = self.apiClient.toPathValue(params['api_key'])
        if ('use_cache' in params):
            queryParams['use_cache'] = self.apiClient.toPathValue(params['use_cache'])
        postData = (params['body'] if 'body' in params else None)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams)

        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'State')
        return responseObject
        
        
    


